'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _getIndexedDB = require('./getIndexedDB');

var _getIndexedDB2 = _interopRequireDefault(_getIndexedDB);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var destroyDatabase = function destroyDatabase(databaseName) {
  var opts = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  return new Promise(function (resolve, reject) {
    var _opts$enableLogging = opts.enableLogging,
        enableLogging = _opts$enableLogging === undefined ? false : _opts$enableLogging;


    try {
      var req = (0, _getIndexedDB2.default)().deleteDatabase(databaseName);

      req.onsuccess = function () {
        if (enableLogging) {
          console.info('Successfully removed IndexedDB: ', databaseName);
        }

        resolve(true);
      };
      req.onerror = function (err) {
        if (enableLogging) {
          console.warn('Unable to delete IndexedDB: ', databaseName);
        }

        reject(err);
      };
      req.onblocked = function (err) {
        if (enableLogging) {
          console.warn('Blocked attempting to delete IndexedDB: ', databaseName);
        }

        reject(err);
      };
    } catch (err) {
      if (enableLogging) {
        console.warn('Unable to initialize IndexedDB deletion: ', databaseName);
      }

      reject(err);
    }
  });
};

exports.default = destroyDatabase;